@@ -485,3 +485,19 @@ def instantiate_delta_table(spark_session: SparkSession, spark_job_conf: dict, t
     table_conf = get_spark_conf(table_name, spark_job_conf['outputs'])
     create_delta_tables_if_not_exists(table_conf, table_conf['delta_options']['schema'])
     return DeltaTable.forPath(spark_session, table_conf['delta_options']['location'])
+
+
+def instantiate_delta_tables(spark_session: SparkSession, spark_job_conf: dict, tables_name: str):
+    tables_conf = get_spark_conf(tables_name, spark_job_conf['outputs'])
+
+    results = dict()
+    for table in tables_conf['delta_options']:
+        DeltaTable \
+            .createIfNotExists() \
+            .addColumns(table['schema']) \
+            .partitionedBy(table["partition_columns"]) \
+            .location(table["location"]) \
+            .execute()
+        results[table['name']] = DeltaTable.forPath(spark_session, table['location'])
+
+    return results
